@@ -1,3 +1,4 @@
+nonIntErr <- 'Non-integers passed to ddelap. These will have 0 probability.'
 VAL <- data.frame(read.csv(file = "./RawTest.csv", header = TRUE))
 SEQUENCE <- seq_len(37) - 1
 
@@ -37,14 +38,17 @@ test_that("Vector NaN", {
                                  c(1, 2, -0.1))), rep(TRUE, 3))
 })
 test_that("Non-integer warning", {
-  expect_warning(ddelap(1.1, 1, 2, 3),
-                 "Non-integers passed to ddelap. These will have 0 probability.")
-  expect_warning(ddelap(c(1, 1.1, 1.2, 3), c(1, 1), 2, 3),
-                 "Non-integers passed to ddelap. These will have 0 probability.")
-  expect_warning(ddelap(seq(2, 3, .1), c(1, 1), 2, 3),
-                 "Non-integers passed to ddelap. These will have 0 probability.")
+  expect_warning(ddelap(1.1, 1, 2, 3), nonIntErr)
+  expect_warning(ddelap(c(1, 1.1, 1.2, 3), c(1, 1), 2, 3), nonIntErr)
+  expect_warning(ddelap(seq(2, 3, .1), c(1, 1), 2, 3), nonIntErr)
 })
 
 test_that("Non-double parameters converted", {
   expect_equal(ddelap(2L, 1L, 2L, 3L), ddelap(2L, 1, 2, 3))
-})
\ No newline at end of file
+})
+
+test_that("Infinite values", {
+  expect_identical(ddelap(Inf, 1L, 2L, 3L), 0)
+  expect_identical(ddelap(c(Inf, Inf), c(1L, 2L), 2L, 3L), c(0, 0))
+  expect_true(is.nan(ddelap(-Inf, 1L, 2L, 3L)))
+})
