@@ -1,5 +1,10 @@
+zeroErr <- 'Parameters must be strictly greater than 0.'
+
 test_that("Singleton exact function accuracy", {
   expect_equal(qdelap(.4, 1, 4, 2), 4)
+  testV <- c(3, 7, 23)
+  expect_equal(qdelap(pdelap(testV, 5L, 2L, 3L), 5L, 2L, 3L),
+               testV)
 })
 test_that("Singleton exact lower.tail", {
   expect_equal(qdelap(0.49, 4, 6, 3, lower.tail = TRUE), 25)
@@ -47,18 +52,17 @@ test_that("Vector exact log.p", {
 })  
 test_that("Vector exact lower.tail & log.p", {
   expect_equal(qdelap(c(-0.69895775020315487, -1.98413706125967337), c(4, 1),
-                      c(6, 9), c(3, 12), lower.tail = FALSE, log.p = TRUE),
-               c(25, 31))
+                      c(6, 9), c(3, 12), lower.tail = FALSE, log.p = TRUE), c(25, 31))
 })
 test_that("Vector Nan", {
-  expect_identical(is.nan(qdelap(seq_len(2)/10, 0, 1, 2)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(2)/10, -1, 1, 2)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(2)/10, 1, 0, 2)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(2)/10, 1, -8, 2)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(2)/10, 3, 1, 0)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(2)/10, 3, 1, -4e-5)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, 0, 1, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, -1, 1, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, 1, 0, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, 1, -8, 2)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, 3, 1, 0)), rep(TRUE, 2))
+  expect_identical(is.nan(qdelap(seq_len(2) / 10, 3, 1, -4e-5)), rep(TRUE, 2))
   expect_identical(is.nan(qdelap(c(-1, -5), 3, 1, 6)), rep(TRUE, 2))
-  expect_identical(is.nan(qdelap(seq_len(3)/10, c(0, 1, 2), c(1, 0, 2),
+  expect_identical(is.nan(qdelap(seq_len(3) / 10, c(0, 1, 2), c(1, 0, 2),
                                  c(1, 2, 0))), rep(TRUE, 3))
 })
 test_that("Vector Inf", {
@@ -66,13 +70,10 @@ test_that("Vector Inf", {
   expect_identical(is.infinite(qdelap(seq_len(3), c(2, 1, 2),
                                       c(1, 6, 2), c(1, 2, 0.4))), rep(TRUE, 3))
 })
-test_that("Approximate throws error when 0 is passed", {
-  expect_error(qdelap(0.1, 0, 2, 3, exact = FALSE),
-               'Parameters must be strictly greater than 0. Please use exact version, if necessary, to prevent spurious results.')
-  expect_error(qdelap(0.1, 1, 0, 3, exact = FALSE),
-               'Parameters must be strictly greater than 0. Please use exact version, if necessary, to prevent spurious results.')
-  expect_error(qdelap(0.1, 1, 2, 0, exact = FALSE),
-               'Parameters must be strictly greater than 0. Please use exact version, if necessary, to prevent spurious results.')
+test_that("Approximate throws error when nonpositive is passed", {
+  expect_error(qdelap(0.1, 0, 2, 3, exact = FALSE), zeroErr)
+  expect_error(qdelap(0.1, 1, 0, 3, exact = FALSE), zeroErr )
+  expect_error(qdelap(0.1, 1, 2, -3, exact = FALSE), zeroErr )
 })
 test_that("Approximate throws error when parameter vectors are passed", {
   expect_error(qdelap(c(.4, .07), c(1, 2), c(4, 1), c(2, 5), exact = FALSE),
